@@ -1,9 +1,8 @@
-from abc import abstractmethod, ABC
-from pybars import Compiler
+from abc import ABC, abstractmethod
 from typing import Any
 
-from pydash import starts_with, is_blank, trim, ends_with, replace, lines
-
+from pybars import Compiler
+from pydash import ends_with, is_blank, lines, replace, starts_with, trim
 
 __compiler__ = Compiler()
 
