@@ -1,9 +1,8 @@
-from typing import Optional, Union, Dict
+from typing import Dict, Optional, Union
 
-from ..lang.decorators import schema, schema_args
-from ..lang.types import SchemaArgs, Schema
-from ..lang.decorators import arg
+from ..lang.decorators import arg, schema, schema_args
 from ..lang.terraform import Terraform
+from ..lang.types import Schema, SchemaArgs
 from .backend.local import Local
 from .backend.remote import Remote
 from .backend.s3 import S3
